@@ -3,7 +3,7 @@ package CGI::Wiki::Setup::Pg;
 use strict;
 
 use vars qw( $VERSION );
-$VERSION = '0.06';
+$VERSION = '0.07';
 
 use DBI;
 use Carp;
@@ -93,7 +93,7 @@ again with a fresh database, run C<cleardb> first.
 =cut
 
 sub setup {
-    my ($dbname, $dbuser, $dbpass, $dbhost) = (@_);
+    my ($dbname, $dbuser, $dbpass, $dbhost) = _get_args(@_);
 
     my $dsn = "dbi:Pg:dbname=$dbname";
     $dsn .= ";host=$dbhost" if $dbhost;
@@ -152,7 +152,7 @@ which search backend you're using.
 =cut
 
 sub cleardb {
-    my ($dbname, $dbuser, $dbpass, $dbhost) = (@_);
+    my ($dbname, $dbuser, $dbpass, $dbhost) = _get_args(@_);
 
     my $dsn = "dbi:Pg:dbname=$dbname";
     $dsn .= ";host=$dbhost" if $dbhost;
@@ -174,8 +174,34 @@ sub cleardb {
     $dbh->disconnect;
 }
 
+sub _get_args {
+    if ( ref $_[0] ) {
+        my %hash = %{$_[0]};
+        return @hash{ qw( dbname dbuser dbpass dbhost ) };
+    } else {
+        return @_;
+    }
+}
+
 =back
 
+=head1 ALTERNATIVE CALLING SYNTAX
+
+As requested by Podmaster.  Instead of passing arguments to the methods as
+
+  ($dbname, $dbuser, $dbpass, $dbhost)
+
+you can pass them as
+
+  ( { dbname => $dbname,
+      dbuser => $dbuser,
+      dbpass => $dbpass,
+      dbhost => $dbhost
+    }
+  )
+
+Note that's a hashref, not a hash.
+
 =head1 AUTHOR
 
 Kake Pugh (kake@earth.li).
